@@ -40,13 +40,13 @@ class HostedAuthorizer(Authorizer):
         self,
         *,
         api_key: str,
-        url: Optional[str] = None,
+        url: str = ASERTO_HOSTED_AUTHORIZER_URL,
         service_type: ServiceType,
     ):
         self._api_key = api_key
         self._service_type = service_type
 
-        if url is not None and url != ASERTO_HOSTED_AUTHORIZER_URL:
+        if url != ASERTO_HOSTED_AUTHORIZER_URL:
             self._url = url
         elif service_type == "gRPC":
             self._url = ASERTO_HOSTED_AUTHORIZER_URL + ":8443"
